Changelog
---------

0.3.3 (2017-01-30)
~~~~~~~~~~~~~~~~~~~

- Upgrade to latest onegov.org/onegov.town releases.
  [href]

0.3.2 (2017-01-19)
~~~~~~~~~~~~~~~~~~~

- Upgrade to latest onegov.org/onegov.town releases.
  [href]

0.3.1 (2017-01-19)
~~~~~~~~~~~~~~~~~~~

- Upgrade to latest onegov.org/onegov.town releases.
  [href]

0.3.0 (2017-01-19)
~~~~~~~~~~~~~~~~~~~

- Upgrade to latest onegov.org/onegov.town releases.
  [href]

- Aligns the design with the new design of onegov.org.
  [href]

- Limit colors to a few hand-selected options.
  [href]

0.2.15 (2017-01-10)
~~~~~~~~~~~~~~~~~~~

- Update to the latest onegov.org/onegov.town releases.
  [href]

0.2.14 (2016-10-26)
~~~~~~~~~~~~~~~~~~~

- Update to the latest onegov.org/onegov.town releases.
  [href]

0.2.13 (2016-09-29)
~~~~~~~~~~~~~~~~~~~

- Update to the latest onegov.org/onegov.town releases.
  [href]

0.2.12 (2016-09-13)
~~~~~~~~~~~~~~~~~~~

- Update to the latest onegov.org/onegov.town releases.
  [href]

0.2.11 (2016-09-12)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town/org release.
  [href]

- Name each step and have a separate body class for each named step.
  [href]

0.2.10 (2016-08-19)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town release.
  [href]

0.2.9 (2016-07-28)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town release.
  [href]

0.2.8 (2016-06-27)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town release.
  [href]

0.2.7 (2016-05-31)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.core and onegov.town releases.
  [href]

0.2.6 (2016-05-30)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.core and onegov.town releases.
  [href]

0.2.5 (2016-05-17)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town release.
  [href]

0.2.4 (2016-05-05)
~~~~~~~~~~~~~~~~~~~

- Depends on latest onegov.town release.
  [href]

0.2.3 (2016-05-02)
~~~~~~~~~~~~~~~~~~~

- Depends on the latest onegov.core and onegov.town release.
  [href]

- Adds Morepath 0.13 compatibility.
  [href]

0.2.2 (2016-04-06)
~~~~~~~~~~~~~~~~~~~

- Depends on the latest onegov.town and onegov.core releases.
  [href]

0.2.1 (2016-02-15)
~~~~~~~~~~~~~~~~~~~

- Depend on latest onegov.core release which fixes an issue with email sending.
  [href]

0.2.0 (2016-02-09)
~~~~~~~~~~~~~~~~~~~

- Includes the latest onegov.town and onegov.core releases.
  [href]

0.1.7 (2016-02-01)
~~~~~~~~~~~~~~~~~~~

- Fix missing default color on Chrome/Firefox.
  [href]

0.1.6 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Sets the initial user as the default reply to address.
  [href]

0.1.5 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Fixes wrong login link in welcome e-mail.
  [href]

0.1.4 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Uses the latest onegov.core and onegov.town release.
  [href]

0.1.3 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Prevents double clicks on submit buttons.
  [href]

- Adds a welcome e-mail.
  [href]

0.1.2 (2016-01-25)
~~~~~~~~~~~~~~~~~~~

- Use latest onegov.town release.
  [href]

0.1.1 (2016-01-23)
~~~~~~~~~~~~~~~~~~~

- Includes the requirements.txt build artifact on the Github Releases page.
  [href]

0.1.0 (2016-01-22)
~~~~~~~~~~~~~~~~~~~

- Initial Release
  [href]